package com.xzzn.ems.service.impl;

import com.xzzn.common.utils.DateUtils;
import com.xzzn.ems.domain.vo.SiteMonitorDataVo;
import com.xzzn.ems.domain.vo.SiteMonitorHomeAlarmVo;
import com.xzzn.ems.domain.vo.SiteMonitorHomeVo;
import com.xzzn.ems.mapper.EmsAlarmRecordsMapper;
import com.xzzn.ems.mapper.EmsPcsDataMapper;
import com.xzzn.ems.service.ISingleSiteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 单点监控 服务层实现
 */
@Service
public class SingleSiteServiceImpl implements ISingleSiteService {

    @Autowired
    private EmsPcsDataMapper emsPcsDataMapper;
    @Autowired
    private EmsAlarmRecordsMapper emsAlarmRecordsMapper;

    @Override
    public SiteMonitorHomeVo getSiteMonitorDataVo(Long siteId) {
        SiteMonitorHomeVo siteMonitorHomeVo = new SiteMonitorHomeVo();

        if (siteId != null) {
            // 实时告警数据 名称+状态+告警内容
            List<SiteMonitorHomeAlarmVo> siteMonitorHomeAlarmVo = emsAlarmRecordsMapper.getAlarmRecordsBySiteId(siteId);
            siteMonitorHomeVo.setSiteMonitorHomeAlarmVo(siteMonitorHomeAlarmVo);
            // 能量数据
            List<SiteMonitorDataVo> siteMonitorDataVoList = emsPcsDataMapper.getPcsDataBySiteId(siteId);
            if (!siteMonitorDataVoList.isEmpty()) {
                BigDecimal totalChargeCap = new BigDecimal(0);
                BigDecimal totalDisChargeCap = new BigDecimal(0);
                for (SiteMonitorDataVo sitePcsData : siteMonitorDataVoList) {
                    // 总充电量
                    totalChargeCap = totalChargeCap.add(sitePcsData.getChargedCap());
                    // 总放电量
                    totalDisChargeCap = totalDisChargeCap.add(sitePcsData.getDisChargedCap());
                    // 获取当天的充电量+放电量
                    Date today = DateUtils.getNowDate();
                    Date pcsDate = DateUtils.parseDate(sitePcsData.getAmmeterDate());
                    if( DateUtils.differentDaysByMillisecond(today,pcsDate) ==0){
                        siteMonitorHomeVo.setDayChargedCap(sitePcsData.getChargedCap());
                        siteMonitorHomeVo.setDayDisChargedCap(sitePcsData.getDisChargedCap());
                    }
                }
                siteMonitorHomeVo.setTotalChargedCap(totalChargeCap);
                siteMonitorHomeVo.setTotalDischargedCap(totalDisChargeCap);
                // 储能可用电量
                BigDecimal energyStorageAvailElec = siteMonitorHomeVo.getTotalDischargedCap().subtract(siteMonitorHomeVo.getTotalChargedCap());
                siteMonitorHomeVo.setEnergyStorageAvailElec(energyStorageAvailElec);
            }
            siteMonitorHomeVo.setSiteMonitorDataVo(siteMonitorDataVoList);
            // 电网实时功率
            siteMonitorHomeVo.setGridNrtPower(emsPcsDataMapper.getGridNrtPower(siteId));
        }

        return siteMonitorHomeVo;
    }

}
